Timeline
========

* 2011 Founding -> CCC Camp MS 0x00
* 2012 Hackathon for Android App 'Social Bearing'
* 2013 Mariner's code: Computer hackers conquering the high seas
* 2014 EuroPython Hackathons
* 2015 Oh, camp again! We did some crowdsourced management

And now, we're here!

You can check all this out on the intertubes. Youtube, CNN, etc.
Just search for 'Hackerfleet' - hmm.. succinct name, eh?
